@@ -8,7 +8,7 @@ import pandas as pd
 from string import Template
 import numpy as np
 from hyperopt import fmin, tpe, hp,space_eval
-
+from hyperopt.pyll import scope
 
 def main(rho,alpha,beta,delta,mu):
     exp_low = [1.38,.041872]
@@ -68,7 +68,7 @@ def optimize():
         beta = 4
         delta=0.03
         mu = 1.67e-5 """
-    space = [hp.uniform('alpha', .01, .5),hp.uniform('beta', 1, 5),hp.uniform('delta', .01, .1),hp.uniform('mu', 1e-5, 1e-6),hp.uniform('rho',320,390)]
+    space = scope.main(hp.uniform('alpha', .01, .5),hp.uniform('beta', 1, 5),hp.uniform('delta', .01, .1),hp.uniform('mu', 1e-5, 1e-6),hp.uniform('rho',320,390))
     best = fmin(main,
     space=space,
     algo=tpe.suggest,
